# This Day In History

Find what happened on a particular day in history.

# Usage


```
thiday -m 1 -m 1 Births

This will output the list of famous births in January 1st.
```

#### Arguments
```
thisday -m [month in number] -d [day in number] [occurance]

-m/--month = month (optional argument),
-d/--day = day (optional argument) and
occurrence = postional argument.

If no arguments are provided then the default value for month and day will be the current date and
Holidays_and_observances will be the default value for occurrence.
```

#### Occurrence Choices
* Events
* Births
* Deaths
* Holidays_and_observances


